==> vgs-collect-react-native-0.0.3.tgz: package/ios/CollectorManager.swift <==
import VGSCollectSDK
import UIKit

@objc(CollectorManager)
class CollectorManager: NSObject {
 static var map: [String: VGSCollect] = [:];

 @objc(createNamedCollector:vaultId:environment:)
 func createNamedCollector(_ name: String, vaultId: String, environment: String) -> Void {
    
    if let existingInstance = CollectorManager.map[name] {
        existingInstance.unsubscribeAllTextFields();
        CollectorManager.map.removeValue(forKey: name);
    }
        
    CollectorManager.map[name] = VGSCollect(id: vaultId, environment: environment);
 }

    @objc(submit:path:method:headers:resolver:rejecter:)
    func submit(_ name: String, path: String, method: String, headers: Dictionary<String, String>, resolver resolve: @escaping RCTPromiseResolveBlock, rejecter reject: @escaping RCTPromiseRejectBlock) -> Void {
    print("Sbmit", name, headers);
        let collector = CollectorManager.map[name]!
        
        if (collector == nil) {
            reject("error", "invalid name", NSError(domain: "MissingCollectorByNameError", code: 401))
            return;
        }
        collector.customHeaders = headers;
    
        collector.sendData(
            path: path,
            method: method == "POST" ? .post : .get
        ) { [weak self](response) in
            switch response {
              case .success(_, let data, _):
                print("success, data: \(data)");
                resolve(data);
                
                return
              case .failure(let code, _, _, let error):
                print("Input data is not valid. Details:\n \(code) \(error)")
                reject("error", error?.localizedDescription, error ?? NSError(domain: "VGSCollectError", code: code));
                
              return
            }
        }
        
        
    }
}

==> vgs-collect-react-native-0.0.4.tgz: package/ios/CollectorManager.swift <==
import VGSCollectSDK
import UIKit

@objc(CollectorManager)
class CollectorManager: NSObject {
 static var map: [String: VGSCollect] = [:];

 @objc(createNamedCollector:vaultId:environment:)
 func createNamedCollector(_ name: String, vaultId: String, environment: String) -> Void {
    
    if let existingInstance = CollectorManager.map[name] {
        existingInstance.unsubscribeAllTextFields();
        CollectorManager.map.removeValue(forKey: name);
    }
        
    CollectorManager.map[name] = VGSCollect(id: vaultId, environment: environment);
 }

    @objc(submit:path:method:headers:resolver:rejecter:)
    func submit(_ name: String, path: String, method: String, headers: Dictionary<String, String>, resolver resolve: @escaping RCTPromiseResolveBlock, rejecter reject: @escaping RCTPromiseRejectBlock) -> Void {
    print("Sbmit", name, headers);
        let collector = CollectorManager.map[name]!
        
        if (collector == nil) {
            reject("error", "invalid name", NSError(domain: "MissingCollectorByNameError", code: 401))
            return;
        }
        collector.customHeaders = headers;
    
        collector.sendData(
            path: path,
            method: method == "POST" ? .post : .get
        ) { [weak self](response) in
            switch response {
              case .success(let code, let data, let response):
                print("success, code= \(code), data: \(data), response: \(response)");
                resolve(["code": code, "data": data, "response": response ]);
                
                return
              case .failure(let code, _, _, let error):
                print("Input data is not valid. Details:\n \(code) \(error)")
                reject("error", error?.localizedDescription, error ?? NSError(domain: "VGSCollectError", code: code));
                
              return
            }
        }
        
        
    }
}
